@@ -76,8 +76,8 @@ def titleSummaryMaker(csv):
     return pool[['title_summary_temp', 'title_summary']]
 
 
-def csvImporter(csv_folder, csv_folder_encoding, csv_folder_cleaned, db_table_name):
-    column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
+def csvImporter(csv_folder, csv_folder_encoding, csv_folder_cleaned, db_table_name, column_name):
+    # column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
 
     fileList = os.listdir(csv_folder_cleaned)
     for i in range(len(fileList)):
@@ -117,8 +117,8 @@ def unicodeProcess(dataframe):
     dataframe['title'] = dataframe['title'].str.replace(' ', ' ')
 
 
-def csvImporter_NEW(csv_folder_cleaned, keyword_pool, skima):
-    column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
+def csvImporter_NEW(csv_folder_cleaned, keyword_pool, skima, column_name):
+    # column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
 
     fileList = os.listdir(csv_folder_cleaned)
     for i in range(len(fileList)):
@@ -161,9 +161,8 @@ def csvImporter_NEW(csv_folder_cleaned, keyword_pool, skima):
             stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name, skima)
 
 
-def keywordCheck(csv_folder_cleaned, pool_check_folder, keyword_pool):
-    column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
-
+def keywordCheck(csv_folder_cleaned, pool_check_folder, keyword_pool, column_name):
+    # column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
 
     pool = keywordPool(keyword_pool)
     title_mapping = titleSummaryMaker(keyword_pool)
@@ -199,6 +198,7 @@ def keywordCheck(csv_folder_cleaned, pool_check_folder, keyword_pool):
 #     csv_folder_encoding = ""
 #     keyword_pool = ""
 #     pool_check_folder = ""
+#     column_name = column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
     
 #     csvPreprocess(csv_folder, csv_folder_cleaned, csv_folder_encoding)
 #     keywordCheck(csv_folder_cleaned, pool_check_folder, keyword_pool)
